#
# spec file for package rspamd
#
# Copyright (c) 2016 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#
%if 0%{?suse_version} > 1230 || 0%{?rhel_version} > 600 || 0%{?centos_version} > 600 || 0%{?fedora_version} >= 20 || 0%{?el7}%{?fc20}%{?fc21}%{?fc22}%{?fc23}%{?fc24}%{?fc25}
%bcond_without systemd
%else
%bcond_with    systemd
%endif

%if 0%{?suse_version} && 0%{suse_version} < 1330
%bcond_without luajit
%else
%bcond_with    luajit
%endif

%define rspamd_user  _rspamd
%define rspamd_group %{rspamd_user}

%global _wwwdir /srv/www/webapps

Name:           rspamd
Version:        1.6.2
Release:        0
License:        Apache-2.0
Summary:        Spam filtering system
Url:            https://rspamd.com/
Group:          Productivity/Networking/Email/Utilities
Source0:        https://rspamd.com/downloads/rspamd-%{version}.tar.xz
Source1:        rspamd.conf

BuildRequires:  cmake
BuildRequires:  curl-devel
BuildRequires:  db-devel
BuildRequires:  file-devel
BuildRequires:  gcc-c++
BuildRequires:  gd-devel
BuildRequires:  jemalloc-devel
BuildRequires:  libfann-devel
BuildRequires:  libicu-devel
%if %{with luajit}
BuildRequires:  luajit-devel
%else
BuildRequires:  lua-devel
%endif
BuildRequires:  pcre-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0) >= 2.28
BuildRequires:  pkgconfig(hiredis)
BuildRequires:  pkgconfig(libevent)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  ragel
%if %{with systemd}
BuildRequires:  pkgconfig(systemd)
%{?systemd_requires}
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Rspamd is a spam filtering system that allows evaluation of messages
by a number of rules including regular expressions, statistical analysis and
custom services such as URL black lists. Each message is analysed by rspamd and
given a "spam score".

According to this spam score and the user's settings, rspamd recommends an
action for the MTA to apply to the message, for example to pass, reject or add
a header.  Rspamd is designed to process hundreds of messages per second
simultaneously and has a number of features available.

%prep
%setup -q

%build
%cmake                                      \
  -DCMAKE_EXE_LINKER_FLAGS:STRING=''        \
  -DCMAKE_MODULE_LINKER_FLAGS:STRING=''     \
  -DCMAKE_SHARED_LINKER_FLAGS:STRING=''     \
  -DRSPAMD_LIBDIR=%{_libdir}/rspamd         \
  -DCONFDIR=%{_sysconfdir}/rspamd           \
  -DMANDIR=%{_mandir}                       \
  -DDBDIR=%{_localstatedir}/lib/rspamd      \
  -DRUNDIR=%{_localstatedir}/run/rspamd     \
  -DLOGDIR=%{_localstatedir}/log/rspamd     \
  -DEXAMPLESDIR=%{_datadir}/examples/rspamd \
  -DPLUGINSDIR=%{_datadir}/rspamd           \
  -DLIBDIR=%{_libdir}/rspamd/               \
  -DINCLUDEDIR=%{_includedir}               \
  -DWWWDIR=%{_wwwdir}/%{name}               \
  -DENABLE_OPTIMIZATION=ON                  \
  -DENABLE_REDIRECTOR=ON                    \
  -DCMAKE_SKIP_INSTALL_RPATH=ON             \
  -DCMAKE_SKIP_RPATH=OFF                    \
  %if %{with luajit}
  -DENABLE_LUAJIT=ON                        \
  %else
  -DENABLE_LUAJIT=OFF                       \
  %endif
  -DENABLE_DB=ON                            \
  -DENABLE_SQLITE=ON                        \
  -DENABLE_HIREDIS=ON                       \
  -DENABLE_URL_INCLUDE=ON                   \
  -DNO_SHARED=ON                            \
  -DINSTALL_EXAMPLES=ON                     \
  -DINSTALL_WEBUI=ON                        \
  %if %{with systemd}
  -DWANT_SYSTEMD_UNITS=ON                   \
  -DSYSTEMDDIR=%{_unitdir}                  \
  %else
  -DWANT_SYSTEMD_UNITS=OFF                  \
  %endif
  %if %{with hyperscan}
  -DENABLE_HYPERSCAN=ON                     \
  %endif
  %if %{with fann}
  -DENABLE_FANN=ON                          \
  %endif
  %if %{with pcre2}
  -DENABLE_PCRE2=ON                         \
  %endif
  %if %{with jemalloc}
  -DENABLE_JEMALLOC=ON                      \
  %endif
  -DDEBIAN_BUILD=1                          \
  -DRSPAMD_GROUP=%{rspamd_group}            \
  -DRSPAMD_USER=%{rspamd_user}              \
  -DDEBIAN_BUILD=1
make %{?_smp_mflags}

%install
%cmake_install
mkdir -p                                   \
  %{buildroot}%{_sbindir}                  \
  %{buildroot}%{_localstatedir}/lib/rspamd \
  %{buildroot}%{_localstatedir}/run/rspamd \
  %{buildroot}%{_localstatedir}/log/rspamd

%if %{with systemd}
ln -fs %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
%endif
ln -s rspamd/librspamd-actrie.so %{buildroot}%{_libdir}

install -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}/local.d
cat > %{buildroot}%{_sysconfdir}/%{name}/local.d/worker-normal.inc << EOF
# If the mailer is running on the same host use a unix socket
#bind_socket = "/run/rspamd/worker.socket mode=0666";
EOF

cat > %{buildroot}%{_sysconfdir}/%{name}/local.d/worker-controller.inc << EOF
# If the mailer is running on the same host use a unix socket
#bind_socket = "/run/rspamd/worker-controller.socket mode=0666";
EOF

cat > %{buildroot}%{_sysconfdir}/%{name}/local.d/worker-proxy.inc << EOF
# If the mailer is running on the same host use a unix socket
#bind_socket = "/run/rspamd/worker-proxy.socket mode=0666";
EOF

install -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}/overrides.d
install -p -m 755 %{SOURCE1} %{buildroot}/%{_sysconfdir}/rspamd/

%pre
%{_sbindir}/groupadd -r %{rspamd_group} 2>/dev/null || :
%{_sbindir}/useradd -g %{rspamd_group} -c "Rmilter user" -s /bin/false -r %{rspamd_user} 2>/dev/null || :
%if 0%{?suse_version} && %{with systemd}
%service_add_pre %{name}.service

%post
#systemd-tmpfiles --create /usr/lib/tmpfiles.d/%{name}.conf ||:
%service_add_post %{name}.service
%endif

%if 0%{?suse_version}
%preun
%if %{with systemd}
%service_del_preun %{name}.service
%else
%stop_on_removal %{name}
%endif
%endif

%if 0%{?suse_version}
%postun
%if %{with systemd}
%service_del_postun %{name}.service
%else
%restart_on_update %{name}
%insserv_cleanup
%endif
%endif


%files
%defattr(-,root,root)
%{_sbindir}/rc%{name}
%{_bindir}/rspamadm
%{_bindir}/rspamc
%{_bindir}/rspamd
%{_bindir}/rspamd-redirector
%{_bindir}/rspamd_stats
%{_libdir}/librspamd-actrie.so

%dir %{_libdir}/rspamd/
%{_libdir}/rspamd/librspamd-actrie.so

%dir %{_sysconfdir}/rspamd/
%config %{_sysconfdir}/rspamd/2tld.inc
%config %{_sysconfdir}/rspamd/common.conf
%config %{_sysconfdir}/rspamd/composites.conf
%config %{_sysconfdir}/rspamd/dmarc_whitelist.inc
%config %{_sysconfdir}/rspamd/logging.inc
%config %{_sysconfdir}/rspamd/maillist.inc
%config %{_sysconfdir}/rspamd/metrics.conf
%config %{_sysconfdir}/rspamd/mid.inc
%config %{_sysconfdir}/rspamd/mime_types.inc
%config %{_sysconfdir}/rspamd/modules.conf
%config %{_sysconfdir}/rspamd/options.inc
%config %{_sysconfdir}/rspamd/redirectors.inc
%config %{_sysconfdir}/rspamd/rspamd.conf
%config %{_sysconfdir}/rspamd/spf_dkim_whitelist.inc
%config %{_sysconfdir}/rspamd/statistic.conf
%config %{_sysconfdir}/rspamd/surbl-whitelist.inc
%config %{_sysconfdir}/rspamd/worker-controller.inc
%config %{_sysconfdir}/rspamd/worker-fuzzy.inc
%config %{_sysconfdir}/rspamd/worker-normal.inc
%config %{_sysconfdir}/rspamd/worker-proxy.inc

%dir %{_sysconfdir}/rspamd/local.d
%config(noreplace) %{_sysconfdir}/rspamd/local.d/worker-controller.inc
%config(noreplace) %{_sysconfdir}/rspamd/local.d/worker-normal.inc
%config(noreplace) %{_sysconfdir}/rspamd/local.d/worker-proxy.inc

%dir %{_sysconfdir}/rspamd/modules.d
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/antivirus.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/arc.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/asn.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/chartable.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/clickhouse.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/dcc.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/dkim.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/dkim_signing.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/dmarc.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/emails.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/fann_redis.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/force_actions.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/forged_recipients.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/fuzzy_check.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/greylist.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/history_redis.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/hfilter.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/ip_score.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/maillist.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/metadata_exporter.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/metric_exporter.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/mid.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/mime_types.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/multimap.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/mx_check.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/once_received.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/phishing.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/ratelimit.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/rbl.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/redis.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/regexp.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/replies.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/milter_headers.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/rspamd_update.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/spamassassin.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/spamtrap.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/spf.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/surbl.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/trie.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/url_redirector.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/url_reputation.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/url_tags.conf
%config(noreplace) %{_sysconfdir}/rspamd/modules.d/whitelist.conf

%dir %{_sysconfdir}/rspamd/overrides.d

%dir %{_datadir}/examples
%dir %{_datadir}/examples/rspamd
%{_datadir}/examples/rspamd/rspamd.conf

%dir %{_datadir}/rspamd
%{_datadir}/rspamd/effective_tld_names.dat

%dir %{_datadir}/rspamd/lua
%{_datadir}/rspamd/lua/antivirus.lua
%{_datadir}/rspamd/lua/arc.lua
%{_datadir}/rspamd/lua/asn.lua
%{_datadir}/rspamd/lua/bayes_expiry.lua
%{_datadir}/rspamd/lua/clickhouse.lua
%{_datadir}/rspamd/lua/dcc.lua
%{_datadir}/rspamd/lua/dkim_signing.lua
%{_datadir}/rspamd/lua/dmarc.lua
%{_datadir}/rspamd/lua/dynamic_conf.lua
%{_datadir}/rspamd/lua/emails.lua
%{_datadir}/rspamd/lua/fann_classifier.lua
%{_datadir}/rspamd/lua/fann_redis.lua
%{_datadir}/rspamd/lua/fann_scores.lua
%{_datadir}/rspamd/lua/force_actions.lua
%{_datadir}/rspamd/lua/forged_recipients.lua
%{_datadir}/rspamd/lua/fuzzy_collect.lua
%{_datadir}/rspamd/lua/greylist.lua
%{_datadir}/rspamd/lua/hfilter.lua
%{_datadir}/rspamd/lua/history_redis.lua
%{_datadir}/rspamd/lua/ip_score.lua
%{_datadir}/rspamd/lua/maillist.lua
%{_datadir}/rspamd/lua/metadata_exporter.lua
%{_datadir}/rspamd/lua/metric_exporter.lua
%{_datadir}/rspamd/lua/mid.lua
%{_datadir}/rspamd/lua/mime_types.lua
%{_datadir}/rspamd/lua/multimap.lua
%{_datadir}/rspamd/lua/mx_check.lua
%{_datadir}/rspamd/lua/once_received.lua
%{_datadir}/rspamd/lua/phishing.lua
%{_datadir}/rspamd/lua/ratelimit.lua
%{_datadir}/rspamd/lua/rbl.lua
%{_datadir}/rspamd/lua/replies.lua
%{_datadir}/rspamd/lua/milter_headers.lua
%{_datadir}/rspamd/lua/rspamd_update.lua
%{_datadir}/rspamd/lua/settings.lua
%{_datadir}/rspamd/lua/spamassassin.lua
%{_datadir}/rspamd/lua/spamtrap.lua
%{_datadir}/rspamd/lua/trie.lua
%{_datadir}/rspamd/lua/url_redirector.lua
%{_datadir}/rspamd/lua/url_reputation.lua
%{_datadir}/rspamd/lua/url_tags.lua
%{_datadir}/rspamd/lua/whitelist.lua

%dir %{_datadir}/rspamd/lib
%{_datadir}/rspamd/lib/auth_results.lua
%{_datadir}/rspamd/lib/dkim_sign_tools.lua
%{_datadir}/rspamd/lib/fun.lua
%{_datadir}/rspamd/lib/global_functions.lua
%{_datadir}/rspamd/lib/lua_redis.lua
%{_datadir}/rspamd/lib/lua_util.lua
%{_datadir}/rspamd/lib/maps.lua
%{_datadir}/rspamd/lib/meta_functions.lua

%dir %{_datadir}/rspamd/rules
%{_datadir}/rspamd/rules/forwarding.lua
%{_datadir}/rspamd/rules/headers_checks.lua
%{_datadir}/rspamd/rules/html.lua
%{_datadir}/rspamd/rules/http_headers.lua
%{_datadir}/rspamd/rules/mid.lua
%{_datadir}/rspamd/rules/misc.lua
%{_datadir}/rspamd/rules/rspamd.classifiers.lua
%{_datadir}/rspamd/rules/rspamd.lua
%{_datadir}/rspamd/rules/subject_checks.lua

%dir %{_datadir}/rspamd/rules/regexp
%{_datadir}/rspamd/rules/regexp/compromised_hosts.lua
%{_datadir}/rspamd/rules/regexp/headers.lua
%{_datadir}/rspamd/rules/regexp/misc.lua
%{_datadir}/rspamd/rules/regexp/upstream_spam_filters.lua

%{_mandir}/man1/rspamadm.1*
%{_mandir}/man1/rspamc.1*
%{_mandir}/man8/rspamd.8*

%{_unitdir}/rspamd.service

%dir %attr(750,%{rspamd_user},%{rspamd_group}) %{_localstatedir}/lib/rspamd
#ghost %dir %attr(750,%{rspamd_user},%{rspamd_group}) %{_localstatedir}/run/rspamd
%dir %attr(750,%{rspamd_user},%{rspamd_group}) %{_localstatedir}/log/rspamd

%dir %{_wwwdir}
%dir %{_wwwdir}/%{name}
%{_wwwdir}/%{name}/README.md
%{_wwwdir}/%{name}/favicon.ico
%{_wwwdir}/%{name}/index.html
%{_wwwdir}/%{name}/plugins.txt
%{_wwwdir}/%{name}/react-index.html

%dir %{_wwwdir}/%{name}/css
%{_wwwdir}/%{name}/css/bootstrap.min.css
%{_wwwdir}/%{name}/css/d3evolution.css
%{_wwwdir}/%{name}/css/footable.bootstrap.min.css
%{_wwwdir}/%{name}/css/rspamd.css

%dir %{_wwwdir}/%{name}/fonts
%{_wwwdir}/%{name}/fonts/glyphicons-halflings-regular.ttf
%{_wwwdir}/%{name}/fonts/glyphicons-halflings-regular.woff
%{_wwwdir}/%{name}/fonts/glyphicons-halflings-regular.woff2

%dir %{_wwwdir}/%{name}/img
%{_wwwdir}/%{name}/img/asc.png
%{_wwwdir}/%{name}/img/desc.png
%{_wwwdir}/%{name}/img/rspamd_logo_navbar.png

%dir %{_wwwdir}/%{name}/js
%{_wwwdir}/%{name}/js/main.js
%{_wwwdir}/%{name}/js/require.js

%dir %{_wwwdir}/%{name}/js/app
%{_wwwdir}/%{name}/js/app/config.js
%{_wwwdir}/%{name}/js/app/graph.js
%{_wwwdir}/%{name}/js/app/history.js
%{_wwwdir}/%{name}/js/app/rspamd.js
%{_wwwdir}/%{name}/js/app/stats.js
%{_wwwdir}/%{name}/js/app/symbols.js
%{_wwwdir}/%{name}/js/app/upload.js

%dir %{_wwwdir}/%{name}/js/lib
%{_wwwdir}/%{name}/js/lib/bootstrap.min.js
%{_wwwdir}/%{name}/js/lib/d3.min.js
%{_wwwdir}/%{name}/js/lib/d3evolution.min.js
%{_wwwdir}/%{name}/js/lib/d3pie.min.js
%{_wwwdir}/%{name}/js/lib/domReady.js
%{_wwwdir}/%{name}/js/lib/footable.min.js
%{_wwwdir}/%{name}/js/lib/humanize.min.js
%{_wwwdir}/%{name}/js/lib/jquery-3.1.1.min.js
%{_wwwdir}/%{name}/js/lib/visibility.min.js
